@@ -65,7 +65,7 @@ class MatterEndpoint:
         self.node = node
         self.endpoint_id = endpoint_id
         self.clusters: dict[int, Clusters.Cluster] = {}
-        self.device_types: set[DeviceType] = set()
+        self.device_types: set[type[DeviceType]] = set()
         self.update(attributes_data)
 
     @property
@@ -79,7 +79,9 @@ class MatterEndpoint:
         return self.node.get_compose_parent(self.endpoint_id) is not None
 
     @property
-    def device_info(self) -> Clusters.BasicInformation | Clusters.BridgedDeviceBasic:
+    def device_info(
+        self,
+    ) -> Clusters.BasicInformation | Clusters.BridgedDeviceBasicInformation:
         """
         Return device info.
 
@@ -169,7 +171,7 @@ class MatterEndpoint:
         Do not modify the data directly from a consumer.
         """
         _, cluster_id, attribute_id = parse_attribute_path(attribute_path)
-        cluster_class: Clusters.Cluster = ALL_CLUSTERS[cluster_id]
+        cluster_class: type[Clusters.Cluster] = ALL_CLUSTERS[cluster_id]
         if cluster_id in self.clusters:
             cluster_instance = self.clusters[cluster_id]
         else:
@@ -177,7 +179,7 @@ class MatterEndpoint:
             self.clusters[cluster_id] = cluster_instance
 
         # unpack cluster attribute, using the descriptor
-        attribute_class: Clusters.ClusterAttributeDescriptor = ALL_ATTRIBUTES[
+        attribute_class: type[Clusters.ClusterAttributeDescriptor] = ALL_ATTRIBUTES[
             cluster_id
         ][attribute_id]
         attribute_name, attribute_type = get_object_params(
@@ -207,7 +209,7 @@ class MatterEndpoint:
 
     def __repr__(self) -> str:
         """Return the representation."""
-        return f"<MatterEndoint {self.endpoint_id} (node {self.node.node_id})>"
+        return f"<MatterEndpoint {self.endpoint_id} (node {self.node.node_id})>"
 
 
 class MatterNode:
@@ -216,7 +218,6 @@ class MatterNode:
     def __init__(self, node_data: MatterNodeData) -> None:
         """Initialize MatterNode from MatterNodeData."""
         self.endpoints: dict[int, MatterEndpoint] = {}
-        self._is_bridge_device: bool = False
         # composed devices reference to other endpoints through the partsList attribute
         # create a mapping table
         self._composed_endpoints: dict[int, int] = {}
@@ -251,7 +252,7 @@ class MatterNode:
     @property
     def is_bridge_device(self) -> bool:
         """Return if this Node is a Bridge/Aggregator device."""
-        return self._is_bridge_device
+        return self.node_data.is_bridge
 
     def get_attribute_value(
         self,
@@ -310,10 +311,6 @@ class MatterNode:
                 self.endpoints[endpoint_id] = MatterEndpoint(
                     endpoint_id=endpoint_id, attributes_data=attributes_data, node=self
                 )
-        # lookup if this is a bridge device
-        self._is_bridge_device = any(
-            Aggregator in x.device_types for x in self.endpoints.values()
-        )
         # composed devices reference to other endpoints through the partsList attribute
         # create a mapping table to quickly map this
         for endpoint in self.endpoints.values():
@@ -339,6 +336,9 @@ class MatterNode:
     def update_attribute(self, attribute_path: str, new_value: Any) -> None:
         """Handle Attribute value update."""
         endpoint_id = int(attribute_path.split("/")[0])
+        if endpoint_id not in self.endpoints:
+            # race condition when a bridge is in the process of adding a new endpoint
+            return
         self.endpoints[endpoint_id].set_attribute_value(attribute_path, new_value)
 
     def __repr__(self) -> str:
