@@ -8,6 +8,7 @@ from datetime import datetime
 from functools import partial
 import logging
 import random
+import time
 from typing import TYPE_CHECKING, Any, Callable, Iterable, Type, TypeVar, cast
 
 from chip.ChipDeviceCtrl import CommissionableNode
@@ -731,6 +732,26 @@ class MatterDeviceController:
             nextResubscribeIntervalMsec: int,
         ) -> None:
             # pylint: disable=unused-argument, invalid-name
+            cur_timestamp = time.time()
+            if (
+                nextResubscribeIntervalMsec > 30000
+                and (cur_timestamp - node.last_subscription_attempt) < 2
+            ):
+                # Guard for a (possible) bug in the sdk where the resubscription gets into
+                # an endloop loop where this callback is hit multiple times per second.
+                node_logger.error(
+                    "Infinite loop detected in resubscription, "
+                    "start manual resubscription logic."
+                )
+                # cancel subscription and add this node to our node polling job
+                sub.Shutdown()
+                self._subscriptions.pop(node_id)
+                assert self.server.loop
+                self.server.loop.create_task(
+                    self._check_interview_and_subscription(node_id, MAX_POLL_INTERVAL)
+                )
+                return
+            node.last_subscription_attempt = cur_timestamp
             node_logger.info(
                 "Previous subscription failed with Error: %s, re-subscribing in %s ms...",
                 terminationError,
@@ -740,20 +761,6 @@ class MatterDeviceController:
             if node.available:
                 node.available = False
                 self.server.signal_event(EventType.NODE_UPDATED, node)
-            if nextResubscribeIntervalMsec / 1000 > MAX_POLL_INTERVAL:
-                # workaround to handle devices that are unplugged
-                # from power for a longer period of time
-                # where the sdk is extending the poll timeout at every attempt
-                # until even 1,5 hours which is way too long.
-                # instead a device back alive should be detected using mDNS,
-                # which is not yet implemented in the core sdk.
-                # For now, we just override the timeout.
-                # NOTE 1: fix this once OperationalNodeDiscovery is available:
-                # https://github.com/project-chip/connectedhomeip/pull/26718
-                # https://github.com/project-chip/connectedhomeip/issues/29663
-                # NOTE 2: We could also just implement zeroconf/mdns ourselves
-                # to listen for the announcements.
-                sub.OverrideLivenessTimeoutMs(MAX_POLL_INTERVAL * 1000)
 
         def resubscription_succeeded(
             transaction: Attribute.SubscriptionTransaction,
